1.0.0 API documentation: GLM_EXT_vector_int4_sized

| 1.0.0 API documentation

Typedefs
GLM_EXT_vector_int4_sized
Stable extensions

## Typedefs
typedef vec< 4, int16, defaultp > | i16vec4
| 16 bit signed integer vector of 4 components type. More...
typedef vec< 4, int32, defaultp > | i32vec4
| 32 bit signed integer vector of 4 components type. More...
typedef vec< 4, int64, defaultp > | i64vec4
| 64 bit signed integer vector of 4 components type. More...
typedef vec< 4, int8, defaultp > | i8vec4
| 8 bit signed integer vector of 4 components type. More...

## Detailed Description

Exposes sized signed integer vector of 4 components type.

Include <glm/ext/vector_int4_sized.hpp> to use the features of this extension.

See also
  GLM_EXT_scalar_int_sized
  GLM_EXT_vector_uint4_sized

## Typedef Documentation

## ◆ i16vec4

typedef vec< 4, i16, defaultp > i16vec4

16 bit signed integer vector of 4 components type.

See also
  GLM_EXT_vector_int4_sized

Definition at line 36 of file vector_int4_sized.hpp.

## ◆ i32vec4

typedef vec< 4, i32, defaultp > i32vec4

32 bit signed integer vector of 4 components type.

See also
  GLM_EXT_vector_int4_sized

Definition at line 41 of file vector_int4_sized.hpp.

## ◆ i64vec4

typedef vec< 4, i64, defaultp > i64vec4

64 bit signed integer vector of 4 components type.

See also
  GLM_EXT_vector_int4_sized

Definition at line 46 of file vector_int4_sized.hpp.

## ◆ i8vec4

typedef vec< 4, i8, defaultp > i8vec4

8 bit signed integer vector of 4 components type.

See also
  GLM_EXT_vector_int4_sized

Definition at line 31 of file vector_int4_sized.hpp.